@@ -55,6 +55,7 @@ pub fn is_proc_name(s: &str) -> bool {
       | "&call-dylib:->str"
       | "&call-dylib:str->vec-str"
       | "&call-dylib:vec-str->tuple-str2"
+      | "&call-dylib:str-vec-str->tuple-str2"
       // external format
       | "parse-cirru"
       | "format-cirru"
@@ -237,6 +238,7 @@ pub fn handle_proc(name: &str, args: &CalcitItems) -> Result<Calcit, String> {
     "&call-dylib:->str" => ffi::call_dylib_to_str(args),
     "&call-dylib:str->vec-str" => ffi::call_dylib_str_to_vec_str(args),
     "&call-dylib:vec-str->tuple-str2" => ffi::call_dylib_vec_str_to_tuple_str2(args),
+    "&call-dylib:str-vec-str->tuple-str2" => ffi::call_dylib_str_vec_str_to_tuple_str2(args),
     // external data format
     "parse-cirru" => meta::parse_cirru(args),
     "format-cirru" => meta::write_cirru(args),
